@@ -5,7 +5,6 @@ test_that(
 
     # contingency tab - without NAs ---------------------------------
 
-    # `{statsExpressions}` output
     set.seed(123)
     df1 <- suppressWarnings(contingency_table(
       data = mtcars,
@@ -15,10 +14,10 @@ test_that(
       conf.level = 0.99
     ))
 
-    # testing all details
+
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(as.character(df1$expression[[1]]))
+    expect_snapshot(df1$expression)
 
     # with counts
     set.seed(123)
@@ -29,10 +28,9 @@ test_that(
       counts = Freq
     )
 
-    # testing all details
     set.seed(123)
     expect_snapshot(select(df2, -expression))
-    expect_snapshot(as.character(df2$expression[[1]]))
+    expect_snapshot(df2$expression)
 
     # contingency tab - with NAs --------------------------------------
 
@@ -45,10 +43,9 @@ test_that(
       conf.level = 0.990
     ))
 
-    # testing all details
     set.seed(123)
     expect_snapshot(select(df3, -expression))
-    expect_snapshot(as.character(df3$expression[[1]]))
+    expect_snapshot(df3$expression)
   }
 )
 
@@ -78,7 +75,6 @@ test_that(
         row.names = c(NA, -4L)
       )
 
-    # `{statsExpressions}` output
     set.seed(123)
     df1 <- suppressWarnings(
       contingency_table(
@@ -91,10 +87,9 @@ test_that(
       )
     )
 
-    # testing all details
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(as.character(df1$expression[[1]]))
+    expect_snapshot(df1$expression)
 
     # paired data with NAs  ---------------------------------------------
 
@@ -110,7 +105,6 @@ test_that(
     paired_data[24, 1] <- NA
     paired_data[65, 1] <- NA
 
-    # `{statsExpressions}` output
     set.seed(123)
     df2 <- suppressWarnings(
       contingency_table(
@@ -123,10 +117,10 @@ test_that(
       )
     )
 
-    # testing all details
+
     set.seed(123)
     expect_snapshot(select(df2, -expression))
-    expect_snapshot(as.character(df2$expression[[1]]))
+    expect_snapshot(df2$expression)
   }
 )
 
@@ -135,7 +129,6 @@ test_that(
   code = {
     # one-sample test (without NAs) -------------------------------------
 
-    # `{statsExpressions}` output
     set.seed(123)
     df1 <- suppressWarnings(contingency_table(
       data = mtcars,
@@ -144,10 +137,9 @@ test_that(
       k = 5
     ))
 
-    # testing all details
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(as.character(df1$expression[[1]]))
+    expect_snapshot(df1$expression)
 
     # with counts
     set.seed(123)
@@ -157,10 +149,9 @@ test_that(
       counts = Freq
     )
 
-    # testing all details
     set.seed(123)
     expect_snapshot(select(df2, -expression))
-    expect_snapshot(as.character(df2$expression[[1]]))
+    expect_snapshot(df2$expression)
 
     # one-sample test (with NAs) -------------------------------------
 
@@ -172,17 +163,19 @@ test_that(
       ratio = c(0.2, 0.2, 0.3, 0.3)
     )
 
-    # testing all details
     set.seed(123)
     expect_snapshot(select(df3, -expression))
-    expect_snapshot(as.character(df3$expression[[1]]))
+    expect_snapshot(df3$expression)
+
+    # edge case
+    expect_null(contingency_table(data.frame(x = "x"), x, type = "bayes"))
   }
 )
 
 test_that(
-  desc = "bayes factor (proportion test)",
+  desc = "bayesian (proportion test)",
   code = {
-    # bayes factor (proportion test) --------------------------------------
+    # bayesian (proportion test) --------------------------------------
 
     # extracting results from where this function is implemented
     set.seed(123)
@@ -193,7 +186,7 @@ test_that(
     )
 
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(as.character(df1$expression[[1]]))
+    expect_snapshot(df1$expression)
 
     # expr
     set.seed(123)
@@ -201,19 +194,18 @@ test_that(
       type = "bayes",
       data = mtcars,
       x = cyl,
-      prior.concentration = 10,
-      top.text = "duh"
+      prior.concentration = 10
     )
 
     expect_snapshot(select(df2, -expression))
-    expect_snapshot(as.character(df2$expression[[1]]))
+    expect_snapshot(df2$expression)
   }
 )
 
 test_that(
-  desc = "bayes factor (contingency tab)",
+  desc = "bayesian (contingency tab)",
   code = {
-    # bayes factor (contingency tab) --------------------------------------
+    # bayesian (contingency tab) --------------------------------------
 
     # extracting results from where this function is implemented
     set.seed(123)
@@ -229,7 +221,7 @@ test_that(
     # objects
     expect_identical(class(df_results), c("tbl_df", "tbl", "data.frame"))
 
-    # check bayes factor values
+    # check bayesian values
     expect_equal(df_results$bf10[[1]], 28.07349, tolerance = 0.001)
 
     # expr
@@ -273,9 +265,9 @@ test_that(
 
     # expr text
     expect_snapshot(list(
-      as.character(expr_text1$expression[[1]]),
-      as.character(expr_text2$expression[[1]]),
-      as.character(expr_text3$expression[[1]])
+      expr_text1$expression,
+      expr_text2$expression,
+      expr_text3$expression
     ))
   }
 )
