@@ -5,7 +5,7 @@ test_that(
 
     # between-subjects -------------------------------------------------------
 
-    # `{statsExpressions}` output
+
     set.seed(123)
     df1 <- oneway_anova(
       type = "robust",
@@ -18,7 +18,7 @@ test_that(
       nboot = 2
     )
 
-    # `{statsExpressions}` output
+
     set.seed(123)
     df2 <- suppressWarnings(oneway_anova(
       type = "robust",
@@ -31,15 +31,15 @@ test_that(
       conf.level = 0.99
     ))
 
-    # testing all details
+
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(as.character(df1$expression[[1]]))
+    expect_snapshot(df1$expression)
+
 
-    # testing all details
     set.seed(123)
     expect_snapshot(select(df2, -expression))
-    expect_snapshot(as.character(df2$expression[[1]]))
+    expect_snapshot(df2$expression)
   }
 )
 
@@ -50,7 +50,7 @@ test_that(
 
     # within-subjects -------------------------------------------------------
 
-    # `{statsExpressions}` output
+
     set.seed(123)
     df1 <- oneway_anova(
       type = "robust",
@@ -61,9 +61,9 @@ test_that(
       paired = TRUE
     )
 
-    # testing all details
+
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(as.character(df1$expression[[1]]))
+    expect_snapshot(df1$expression)
   }
 )
