@@ -17,10 +17,10 @@ test_that(
         conf.level = 0.90
       )
 
-    # testing all details
+
     set.seed(123)
     expect_snapshot(select(df, -expression))
-    expect_snapshot(as.character(df$expression[[1]]))
+    expect_snapshot(df$expression)
   }
 )
 
@@ -74,10 +74,10 @@ test_that(
         paired = TRUE
       ))
 
-    # testing all details
+
     set.seed(123)
     expect_snapshot(select(df2, -expression))
-    expect_snapshot(as.character(df2$expression[[1]]))
+    expect_snapshot(df2$expression)
   }
 )
 
