@@ -19,10 +19,10 @@ test_that(
       )
     )
 
-    # testing all details
+
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(as.character(df1$expression[[1]]))
+    expect_snapshot(df1$expression)
   }
 )
 
@@ -45,10 +45,10 @@ test_that(
       )
     )
 
-    # testing all details
+
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(as.character(df1$expression[[1]]))
+    expect_snapshot(df1$expression)
   }
 )
 
@@ -72,10 +72,10 @@ test_that(
       conf.level = 0.50
     ))
 
-    # testing all details
+
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(as.character(df1$expression[[1]]))
+    expect_snapshot(df1$expression)
   }
 )
 
@@ -96,10 +96,10 @@ test_that(
       k = 3
     )
 
-    # testing all details
+
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(as.character(df1$expression[[1]]))
+    expect_snapshot(df1$expression)
   }
 )
 
