@@ -19,10 +19,10 @@ test_that(
       k = 4
     )
 
-    # testing all details
+
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(as.character(df1$expression[[1]]))
+    expect_snapshot(df1$expression)
   }
 )
 
@@ -40,10 +40,10 @@ test_that(
       k = 3L
     )
 
-    # testing all details
+
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(as.character(df1$expression[[1]]))
+    expect_snapshot(df1$expression)
   }
 )
 
@@ -65,10 +65,10 @@ test_that(
       k = 3
     )
 
-    # testing all details
+
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(as.character(df1$expression[[1]]))
+    expect_snapshot(df1$expression)
   }
 )
 
@@ -87,10 +87,10 @@ test_that(
       k = 4
     )
 
-    # testing all details
+
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(as.character(df1$expression[[1]]))
+    expect_snapshot(df1$expression)
   }
 )
 
